==> gcr-3.3.92.tar.xz: gcr-3.3.92/gcr/gcr-enum-types-base.h <==

/* Generated data (by glib-mkenums) */

#if !defined (__GCR_INSIDE_HEADER__) && !defined (GCR_COMPILATION)
#error "Only <gcr/gcr.h> can be included directly."
#endif

#ifndef __GCR_ENUM_TYPES_H__
#define __GCR_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "gcr-certificate-chain.h" */
GType gcr_certificate_chain_status_get_type (void) G_GNUC_CONST;
#define GCR_TYPE_CERTIFICATE_CHAIN_STATUS (gcr_certificate_chain_status_get_type ())
GType gcr_certificate_chain_flags_get_type (void) G_GNUC_CONST;
#define GCR_TYPE_CERTIFICATE_CHAIN_FLAGS (gcr_certificate_chain_flags_get_type ())

/* enumerations from "gcr-certificate-request.h" */
GType gcr_certificate_request_format_get_type (void) G_GNUC_CONST;
#define GCR_TYPE_CERTIFICATE_REQUEST_FORMAT (gcr_certificate_request_format_get_type ())

/* enumerations from "gcr-deprecated-base.h" */
GType gcr_importer_prompt_behavior_get_type (void) G_GNUC_CONST;
#define GCR_TYPE_IMPORTER_PROMPT_BEHAVIOR (gcr_importer_prompt_behavior_get_type ())

/* enumerations from "gcr-prompt.h" */
GType gcr_prompt_reply_get_type (void) G_GNUC_CONST;
#define GCR_TYPE_PROMPT_REPLY (gcr_prompt_reply_get_type ())

/* enumerations from "gcr-system-prompt.h" */
GType gcr_system_prompt_error_get_type (void) G_GNUC_CONST;
#define GCR_TYPE_SYSTEM_PROMPT_ERROR (gcr_system_prompt_error_get_type ())

/* enumerations from "gcr-system-prompter.h" */
GType gcr_system_prompter_mode_get_type (void) G_GNUC_CONST;
#define GCR_TYPE_SYSTEM_PROMPTER_MODE (gcr_system_prompter_mode_get_type ())

/* enumerations from "gcr-types.h" */
GType gcr_data_error_get_type (void) G_GNUC_CONST;
#define GCR_TYPE_DATA_ERROR (gcr_data_error_get_type ())
GType gcr_data_format_get_type (void) G_GNUC_CONST;
#define GCR_TYPE_DATA_FORMAT (gcr_data_format_get_type ())
G_END_DECLS

#endif /* __GCR_ENUM_TYPES_H__ */

/* Generated data ends here */

==> gcr_3.10.1.orig.tar.xz: gcr-3.10.1/gcr/gcr-enum-types-base.h <==

/* Generated data (by glib-mkenums) */


#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "gcr-certificate-chain.h" */
#ifndef GCR_TYPE_CERTIFICATE_CHAIN_STATUS
GType gcr_certificate_chain_status_get_type (void) G_GNUC_CONST;
#define GCR_TYPE_CERTIFICATE_CHAIN_STATUS (gcr_certificate_chain_status_get_type ())
#endif

#ifndef GCR_TYPE_CERTIFICATE_CHAIN_FLAGS
GType gcr_certificate_chain_flags_get_type (void) G_GNUC_CONST;
#define GCR_TYPE_CERTIFICATE_CHAIN_FLAGS (gcr_certificate_chain_flags_get_type ())
#endif


/* enumerations from "gcr-certificate-request.h" */
#ifndef GCR_TYPE_CERTIFICATE_REQUEST_FORMAT
GType gcr_certificate_request_format_get_type (void) G_GNUC_CONST;
#define GCR_TYPE_CERTIFICATE_REQUEST_FORMAT (gcr_certificate_request_format_get_type ())
#endif


/* enumerations from "gcr-column.h" */
#ifndef GCR_TYPE_COLUMN_FLAGS
GType gcr_column_flags_get_type (void) G_GNUC_CONST;
#define GCR_TYPE_COLUMN_FLAGS (gcr_column_flags_get_type ())
#endif


/* enumerations from "gcr-deprecated-base.h" */
#ifndef GCR_TYPE_IMPORTER_PROMPT_BEHAVIOR
GType gcr_importer_prompt_behavior_get_type (void) G_GNUC_CONST;
#define GCR_TYPE_IMPORTER_PROMPT_BEHAVIOR (gcr_importer_prompt_behavior_get_type ())
#endif


/* enumerations from "gcr-prompt.h" */
#ifndef GCR_TYPE_PROMPT_REPLY
GType gcr_prompt_reply_get_type (void) G_GNUC_CONST;
#define GCR_TYPE_PROMPT_REPLY (gcr_prompt_reply_get_type ())
#endif


/* enumerations from "gcr-system-prompt.h" */
#ifndef GCR_TYPE_SYSTEM_PROMPT_ERROR
GType gcr_system_prompt_error_get_type (void) G_GNUC_CONST;
#define GCR_TYPE_SYSTEM_PROMPT_ERROR (gcr_system_prompt_error_get_type ())
#endif


/* enumerations from "gcr-system-prompter.h" */
#ifndef GCR_TYPE_SYSTEM_PROMPTER_MODE
GType gcr_system_prompter_mode_get_type (void) G_GNUC_CONST;
#define GCR_TYPE_SYSTEM_PROMPTER_MODE (gcr_system_prompter_mode_get_type ())
#endif


/* enumerations from "gcr-types.h" */
#ifndef GCR_TYPE_DATA_ERROR
GType gcr_data_error_get_type (void) G_GNUC_CONST;
#define GCR_TYPE_DATA_ERROR (gcr_data_error_get_type ())
#endif

#ifndef GCR_TYPE_DATA_FORMAT
GType gcr_data_format_get_type (void) G_GNUC_CONST;
#define GCR_TYPE_DATA_FORMAT (gcr_data_format_get_type ())
#endif

G_END_DECLS


/* Generated data ends here */
